@@ -1,22 +1,22 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2007 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  This program is free software which I release under the GNU General Public
-|  License. You may redistribute and/or modify this program under the terms
-|  of that license as published by the Free Software Foundation; either
-|  version 2 of the License, or (at your option) any later version.
 |
-|  This program is distributed in the hope that it will be useful,
-|  but WITHOUT ANY WARRANTY; without even the implied warranty of
-|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-|  GNU General Public License for more details.  Version 2 is in the
-|  COPYRIGHT file in the top level directory of this distribution.
-| 
-|  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  GKrellM is free software: you can redistribute it and/or modify it
+|  under the terms of the GNU General Public License as published by
+|  the Free Software Foundation, either version 3 of the License, or
+|  (at your option) any later version.
+|
+|  GKrellM is distributed in the hope that it will be useful, but WITHOUT
+|  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+|  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+|  License for more details.
+|
+|  You should have received a copy of the GNU General Public License
+|  along with this program. If not, see http://www.gnu.org/licenses/
 */
 
 
@@ -183,6 +183,9 @@ void		gkrellm_insert_krell_nth(GkrellmPanel *, GkrellmKrell *, gint);
 GkrellmDecal *gkrellm_create_decal_text(GkrellmPanel *p, gchar *string,
 						GkrellmTextstyle *ts, GkrellmStyle *style,
 						gint x, gint y, gint w);
+GkrellmDecal *gkrellm_create_decal_text_markup(GkrellmPanel *p, gchar *string,
+						GkrellmTextstyle *ts, GkrellmStyle *style,
+						gint x, gint y, gint w);
 GkrellmDecal *gkrellm_create_decal_text_with_height(GkrellmPanel *p,
 						GkrellmTextstyle *ts, GkrellmStyle *style,
 						gint x, gint y, gint w, gint h, gint y_pad);
@@ -196,11 +199,17 @@ void		gkrellm_draw_decal_pixmap(GkrellmPanel *, GkrellmDecal *, gint);
 void		gkrellm_draw_decal_text(GkrellmPanel *, GkrellmDecal *, gchar *,
 						gint);
 void		gkrellm_draw_decal_markup(GkrellmPanel *, GkrellmDecal *, gchar *);
+void		gkrellm_decal_text_get_offset(GkrellmDecal *d, gint *x, gint *y);
+void		gkrellm_decal_text_set_offset(GkrellmDecal *d, gint x, gint y);
 void		gkrellm_decal_text_clear(GkrellmDecal *d);
 void		gkrellm_decal_text_insert(GkrellmDecal *d, gchar *s,
 						GkrellmTextstyle *ts, gint x_off, gint y_off);
-void		gkrellm_decal_text_set_offset(GkrellmDecal *d, gint x, gint y);
-void		gkrellm_decal_text_get_offset(GkrellmDecal *d, gint *x, gint *y);
+void		gkrellm_decal_text_markup_insert(GkrellmDecal *d, gchar *s,
+						GkrellmTextstyle *ts, gint x_off, gint y_off);
+void		gkrellm_decal_text_nth_inserted_set_offset(GkrellmDecal *d,
+						gint n, gint x_off, gint y_off);
+void		gkrellm_decal_text_nth_inserted_get_offset(GkrellmDecal *d,
+						gint n, gint *x_off, gint *y_off);
 void		gkrellm_decal_scroll_text_align_center(GkrellmDecal *d,
 						gboolean center);
 void		gkrellm_decal_scroll_text_horizontal_loop(GkrellmDecal *d,
@@ -332,6 +341,7 @@ gfloat		gkrellm_get_theme_scale(void);
 void		gkrellm_open_config_window(GkrellmMonitor *);
 gboolean	gkrellm_config_window_shown(void);
 void		gkrellm_config_modified(void);
+void		gkrellm_config_instant_apply(GkrellmMonitor *mon);
 GkrellmMargin *gkrellm_get_style_margins(GkrellmStyle *);
 void		gkrellm_set_style_margins(GkrellmStyle *, GkrellmMargin *);
 void		gkrellm_get_top_bottom_margins(GkrellmStyle *, gint *, gint *);
@@ -468,6 +478,16 @@ GkrellmTicks *gkrellm_ticks(void);
 void		gkrellm_allow_scaling(gboolean *, gint *);
 gint		gkrellm_plugin_debug(void);
 
+
+  /* Exporting plugin labels to display on monitor panels or charts
+  */
+gint		gkrellm_plugin_export_label(GkrellmMonitor *mon_plugin,
+					gchar *mon_name,
+            		gchar key, gchar *(*func)(gchar key, gchar *which));
+void		gkrellm_plugin_cancel_label(GkrellmMonitor *mon_plugin, gint id);
+gchar		*gkrellm_plugin_get_exported_label(GkrellmMonitor *mon,
+					gchar key, gchar *which);
+
   /* Wrappers around gtk widget functions to provide a convenience higher level
   |  interface for creating the config pages.
   */
@@ -504,6 +524,11 @@ GtkWidget	*gkrellm_gtk_scrolled_text_view(GtkWidget *, GtkWidget **,
 void		gkrellm_gtk_text_view_append_strings(GtkWidget *, gchar **, gint);
 void		gkrellm_gtk_text_view_append(GtkWidget *, gchar *);
 
+GtkTreeSelection *gkrellm_gtk_scrolled_selection(GtkTreeView *treeview,
+			GtkWidget *box, GtkSelectionMode s_mode,
+			GtkPolicyType h_policy, GtkPolicyType v_policy,
+			void (*func_cb)(), gpointer data);
+
 
   /* Some utility functions
   */
@@ -561,17 +586,33 @@ void		gkrellm_client_plugin_serve_data_connect(GkrellmMonitor *mon,
 					gchar *key_name, void (*func_cb)(gchar *line));
 void		gkrellm_client_plugin_reconnect_connect(gchar *key_name,
 					void (*func_cb)());
-
+gboolean	gkrellm_client_send_to_server(gchar *key_name, gchar *line);
+gboolean	gkrellm_client_check_server_version(gint major,
+					gint minor, gint rev);
 
 /* ------- Some aids for using PangoFontDescription -------*/
-void	gkrellm_text_extents(PangoFontDescription *font_desc, gchar *text,
-					gint len, gint *width, gint *height, gint *baseline,
-					gint *y_ink);
+void	gkrellm_text_extents(PangoFontDescription *font_desc,
+					gchar *text, gint len, gint *width, gint *height,
+					gint *baseline, gint *y_ink);
+void	gkrellm_text_markup_extents(PangoFontDescription *font_desc,
+					gchar *text, gint len, gint *width, gint *height,
+					gint *baseline, gint *y_ink);
 
 gint	gkrellm_gdk_string_width(PangoFontDescription *, gchar *);
+gint	gkrellm_gdk_string_markup_width(PangoFontDescription *, gchar *);
+gint	gkrellm_gdk_text_width(PangoFontDescription *font_desc,
+					const gchar *string, gint len);
+gint	gkrellm_gdk_text_markup_width(PangoFontDescription *font_desc,
+					const gchar *string, gint len);
 void	gkrellm_gdk_draw_string(GdkDrawable *drawable,
 					PangoFontDescription *font,
 					GdkGC *gc, gint x, gint y, gchar *string);
+void	gkrellm_gdk_draw_string_markup(GdkDrawable *drawable,
+					PangoFontDescription *font,
+					GdkGC *gc, gint x, gint y, gchar *string);
 void	gkrellm_gdk_draw_text(GdkDrawable *drawable,
 					PangoFontDescription *font,
 					GdkGC *gc, gint x, gint y, gchar *string, gint len);
+void	gkrellm_gdk_draw_text_markup(GdkDrawable *drawable,
+					PangoFontDescription *font,
+					GdkGC *gc, gint x, gint y, gchar *string, gint len);
