@@ -1,24 +1,28 @@
 /* GKrellM
-|  Copyright (C) 1999-2004 Bill Wilson
+|  Copyright (C) 1999-2007 Bill Wilson
 |
-|  Author:  Bill Wilson    bill@gkrellm.net
+|  Author:  Bill Wilson    billw@gkrellm.net
 |  Latest versions might be found at:  http://gkrellm.net
 |
-|  This program is free software which I release under the GNU General Public
-|  License. You may redistribute and/or modify this program under the terms
-|  of that license as published by the Free Software Foundation; either
-|  version 2 of the License, or (at your option) any later version.
 |
-|  This program is distributed in the hope that it will be useful,
-|  but WITHOUT ANY WARRANTY; without even the implied warranty of
-|  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-|  GNU General Public License for more details.  Version 2 is in the
-|  COPYRIGHT file in the top level directory of this distribution.
-| 
-|  To get a copy of the GNU General Puplic License, write to the Free Software
-|  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
+|  GKrellM is free software: you can redistribute it and/or modify it
+|  under the terms of the GNU General Public License as published by
+|  the Free Software Foundation, either version 3 of the License, or
+|  (at your option) any later version.
+|
+|  GKrellM is distributed in the hope that it will be useful, but WITHOUT
+|  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
+|  or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public
+|  License for more details.
+|
+|  You should have received a copy of the GNU General Public License
+|  along with this program. If not, see http://www.gnu.org/licenses/
 */
 
+
+#ifndef GKRELLM_H
+#define GKRELLM_H
+
 #if defined(HAVE_CONFIG_H)
 #include "config.h"
 #endif  
@@ -39,7 +43,8 @@
 #if !defined(WIN32)
 #include <unistd.h>
 #else
-#include "win32.h"
+    #include <winsock2.h>
+    #include <process.h>
 #endif
 
 #include <sys/stat.h>
@@ -52,7 +57,7 @@
 
 #if !defined(__FreeBSD__) && !defined(__linux__) && !defined(__NetBSD__) \
 	&& !defined(__OpenBSD__) && !defined(__solaris__) && !defined(WIN32) \
-	&& !defined(__APPLE__)
+	&& !defined(__APPLE__) && !defined(__DragonFly__)
 #define  USE_LIBGTOP
 #endif
 
@@ -88,7 +93,7 @@
 /* -------------------------------------------------------------------
 */
 #define	GKRELLM_VERSION_MAJOR	2
-#define	GKRELLM_VERSION_MINOR	2
+#define	GKRELLM_VERSION_MINOR	3
 #define	GKRELLM_VERSION_REV		1
 #define	GKRELLM_EXTRAVERSION	""
 
@@ -125,14 +130,10 @@
 
 #else
 
-#define     LOCAL_THEMES_DIR		"./themes"
-#if !defined(SYSTEM_THEMES_DIR)
+#undef      LOCAL_THEMES_DIR
 #define     SYSTEM_THEMES_DIR		"./themes"
-#endif
-#define     LOCAL_PLUGINS_DIR		"./plugins"
-#if !defined(SYSTEM_PLUGINS_DIR)
+#undef      LOCAL_PLUGINS_DIR
 #define     SYSTEM_PLUGINS_DIR		"./plugins"
-#endif
 
 #endif
 
@@ -373,6 +374,8 @@ typedef struct
 #define	GKRELLMSTYLE_TRANSPARENCY		0x20000
 #define	GKRELLMSTYLE_KRELL_YOFF_NOT_SCALABLE 0x40000
 #define	GKRELLMSTYLE_SCROLL_TEXT_CACHE_OFF	 0x80000
+#define	GKRELLMSTYLE_LABEL_YOFF			0x100000
+
 
   /* Some of these style entries do not apply to all monitors.
   */
@@ -389,7 +392,7 @@ typedef struct
 	gint		krell_left_margin,
 				krell_right_margin;
 	gboolean	krell_yoff_not_scalable;
-	gint		krell_spare;
+	gint		label_yoff;
 	gint		label_position;
 	gboolean	scroll_text_cache_off;
 	gint		spare0;
@@ -1019,7 +1022,8 @@ typedef struct
 					from_command_line,
 					spacers_shown,
 					cap_images_off,
-					spacer_overlap_off;
+					spacer_overlap_off,
+					instant_apply;
 	GkrellmStyle	*panel_style,
 					*chart_style;
 	gchar			*style_name;
@@ -1058,7 +1062,8 @@ typedef struct _GkrellmMonitor
 	}
 	GkrellmMonitor;
 
-extern GList	*gkrellm_monitor_list;
-
 
 #include "gkrellm-public-proto.h"
+
+#endif // GKRELLM_H
+
